@@ -1,6 +1,6 @@
 /*
     orzcharlist
-    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2007 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -80,15 +80,8 @@ orz_charlist_get_type (void)
 static void
 orz_charlist_class_init (OrzCharlistClass *klass)
 {
-  GObjectClass *gobject_class;
-  GtkObjectClass *object_class;
-  GtkWidgetClass *widget_class;
   GtkBindingSet *binding_set;
 
-  gobject_class = (GObjectClass*) klass;
-  object_class = (GtkObjectClass*) klass;
-  widget_class = (GtkWidgetClass*) klass;
-
   parent_class = g_type_class_peek_parent (klass);
 
   klass->escape = orz_charlist_escape;
@@ -458,7 +451,7 @@ orz_charlist_init (OrzCharlist *charlist)
 ******************************************************************************/
 /*  ja:新規作成
     RET,ウィジェット                                                        */
-GtkWidget*
+GtkWidget *
 orz_charlist_new (void)
 {
   return GTK_WIDGET (g_object_new (ORZ_TYPE_CHARLIST, NULL));
