@@ -14,7 +14,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
 #ifndef __ABORT_H__
 #define __ABORT_H__
@@ -37,9 +37,9 @@ extern gboolean userbreak;
 *                                                                             *
 ******************************************************************************/
 /*  ja:中断ダイアログ表示
-    label,説明文                                                            */
+    text,説明文                                                             */
 GtkWidget *
-abort_dialog (const gchar *label);
+abort_dialog (const gchar *text);
 
 
 #ifdef __cplusplus
