@@ -1,6 +1,6 @@
 /*
     Melody maid
-    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2007 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -72,15 +72,8 @@ mm_dialog_get_type (void)
 static void
 mm_dialog_class_init (MmDialogClass *klass)
 {
-  GObjectClass *gobject_class;
-  GtkObjectClass *object_class;
-  GtkWidgetClass *widget_class;
   GtkBindingSet *binding_set;
 
-  gobject_class = (GObjectClass *)klass;
-  object_class = (GtkObjectClass *)klass;
-  widget_class = (GtkWidgetClass *)klass;
-
   parent_class = g_type_class_peek_parent (klass);
 
   klass->escape = mm_dialog_escape;
