@@ -1,6 +1,6 @@
 /*
     Melody maid
-    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2007 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -81,14 +81,9 @@ mm_list_get_type (void)
 static void
 mm_list_class_init (MmListClass *klass)
 {
-  GObjectClass *gobject_class;
   GtkObjectClass *object_class;
-  GtkWidgetClass *widget_class;
 
-  gobject_class = (GObjectClass *)klass;
   object_class = (GtkObjectClass *)klass;
-  widget_class = (GtkWidgetClass *)klass;
-
   parent_class = g_type_class_peek_parent (klass);
 
   object_class->destroy = mm_list_destroy;
