@@ -1,6 +1,6 @@
 /*
     Melody maid
-    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2007 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -218,12 +218,12 @@ main (int   argc,
       def_width = g_key_file_get_integer (key_file, "pref", "width", NULL);
       def_height = g_key_file_get_integer (key_file, "pref", "height", NULL);
       n_pos = g_key_file_get_integer (key_file, "pref", "npos", NULL);
-      def_hold = g_key_file_get_boolean (key_file, "mmaid", "def_hold", NULL);
-      def_gnum = g_key_file_get_integer (key_file, "mmaid", "def_gnum", NULL);
+      def_hold = g_key_file_get_boolean (key_file, "mmaid", "defhold", NULL);
+      def_gnum = g_key_file_get_integer (key_file, "mmaid", "defgnum", NULL);
       playlist = g_key_file_get_integer (key_file, "mmaid", "playlist", NULL);
-      cmd_play = g_key_file_get_string (key_file, "mmaid", "cmd_play", NULL);
-      cmd_stop = g_key_file_get_string (key_file, "mmaid", "cmd_stop", NULL);
-      charset_list = g_key_file_get_string (key_file, "mmaid", "charset_list",
+      cmd_play = g_key_file_get_string (key_file, "mmaid", "cmdplay", NULL);
+      cmd_stop = g_key_file_get_string (key_file, "mmaid", "cmdstop", NULL);
+      charset_list = g_key_file_get_string (key_file, "mmaid", "charsetlist",
                                                                         NULL);
       if (charset_list)
         {
@@ -543,7 +543,7 @@ MMAID_COPYRIGHT_NOTICE"\n"
   if (newfile && count <= 0)
     file_open_edit (NULL);
 
-  gtk_main();
+  gtk_main ();
 
   /* ja:レジストリに書き込む */
   if (user_config)
@@ -561,18 +561,18 @@ MMAID_COPYRIGHT_NOTICE"\n"
       g_key_file_set_integer (key_file, "pref", "width", def_width);
       g_key_file_set_integer (key_file, "pref", "height", def_height);
       g_key_file_set_integer (key_file, "pref", "npos", n_pos);
-      g_key_file_set_boolean (key_file, "mmaid", "def_hold", def_hold);
-      g_key_file_set_integer (key_file, "mmaid", "def_gnum", def_gnum);
+      g_key_file_set_boolean (key_file, "mmaid", "defhold", def_hold);
+      g_key_file_set_integer (key_file, "mmaid", "defgnum", def_gnum);
       g_key_file_set_integer (key_file, "mmaid", "playlist", playlist);
-      g_key_file_set_string (key_file, "mmaid", "charset_list", charset_list);
+      g_key_file_set_string (key_file, "mmaid", "charsetlist", charset_list);
       if (cmd_play)
-        g_key_file_set_string (key_file, "mmaid", "cmd_play", cmd_play);
+        g_key_file_set_string (key_file, "mmaid", "cmdplay", cmd_play);
       else
-        g_key_file_remove_key (key_file, "mmaid", "cmd_play", NULL);
+        g_key_file_remove_key (key_file, "mmaid", "cmdplay", NULL);
       if (cmd_stop)
-        g_key_file_set_string (key_file, "mmaid", "cmd_stop", cmd_stop);
+        g_key_file_set_string (key_file, "mmaid", "cmdstop", cmd_stop);
       else
-        g_key_file_remove_key (key_file, "mmaid", "cmd_stop", NULL);
+        g_key_file_remove_key (key_file, "mmaid", "cmdstop", NULL);
       if (open_path)
         {
           gchar *utf8str;
